@@ -2,6 +2,7 @@ import json
 import logging
 
 from fastapi.exceptions import RequestValidationError
+from starlette.exceptions import HTTPException
 
 from web_error.error import HttpException
 from web_error.handler import starlette
@@ -19,6 +20,10 @@ def exception_handler(request: starlette.Request, exc: Exception):
         "code": None,
     }
 
+    if isinstance(exc, HTTPException):
+        response["message"] = exc.detail
+        status = exc.status_code
+
     if isinstance(exc, RequestValidationError):
         response["message"] = "Request validation error."
         response["debug_message"] = json.loads(exc.json())
